"""
use asyncio_run to run any coroutine in any moment, without being called from a async function
Useful to execute a coroutine in debug console
"""
import asyncio

import nest_asyncio


def asyncio_run(future, as_task=True):
    """
    Runs an async task asynchronously.
    Copied from https://stackoverflow.com/a/63593888
    A better implementation of `asyncio.run`.

    :param future: A future or task or call of an async method.
    :param as_task: Forces the future to be scheduled as task (needed for e.g. aiohttp).
    """

    try:
        loop = asyncio.get_running_loop()
    except RuntimeError:  # no event loop running:
        loop = asyncio.new_event_loop()
        return loop.run_until_complete(_to_task(future, as_task, loop))
    else:
        nest_asyncio.apply(loop)
        return asyncio.run(_to_task(future, as_task, loop))


def _to_task(future, as_task, loop):
    if not as_task or isinstance(future, asyncio.Task):
        return future
    return loop.create_task(future)
